@@ -2,6 +2,7 @@ from django.conf import settings
 from django.db import models
 from djangoldp_conversation.models import Conversation, Message
 from djangoldp.models import Model
+from djangoldp_circle.models import Circle
 from django.contrib.auth import get_user_model
 
 class Type (Model):
@@ -34,11 +35,11 @@ class Resource (Model):
     document = models.URLField(blank=True, null=True, verbose_name="Document")
     link = models.CharField(max_length=150, blank=True, null=True, verbose_name="Internet link")
     conversations = models.ManyToManyField(Conversation, blank=True, related_name='resources')
-
+    circle = models.ForeignKey(Circle, null=True, related_name="resources")
 
     class Meta : 
         serializer_fields=["@id", "name", "shortdesc", "longdesc", "type", "img", "document",\
-                           "link", "keywords", "conversations"]
+                           "link", "keywords", "conversations", "circle"]
         auto_author = 'user'
         owner_field = 'user'
         container_path = 'resources/'
